competitions support library for matches
========================================

The goal of this package is to provide match discovery support for the
competitions series of packages.

This package will include simple default match simulators to support basic usage
of this system with competitions-cup and competitions-league, among others.

Changes in v0.2
---------------

- Generic competitor fields
- Walkover detection for two-competitor matches
- Modified class hierarchy

.. image:: https://travis-ci.org/happy5214/competitions-match.svg?branch=master
    :alt: Build status
    :target: https://travis-ci.org/happy5214/competitions-match
.. image:: https://coveralls.io/repos/happy5214/competitions-match/badge.svg?branch=master&service=github
    :alt: Coverage status
    :target: https://coveralls.io/github/happy5214/competitions-match?branch=master
.. image:: https://codeclimate.com/github/happy5214/competitions-match/badges/gpa.svg
    :target: https://codeclimate.com/github/happy5214/competitions-match
    :alt: Code Climate
